==> haskell-nothunks-0.2.0-43-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nothunks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nothunks
version:              0.2.0
visibility:           public
id:                   nothunks-0.2.0-2ulzmpjUEa322mVC3x8bCg
key:                  nothunks-0.2.0-2ulzmpjUEa322mVC3x8bCg
license:              Apache-2.0
copyright:            2018-2024 Input Output Global Inc (IOG)
maintainer:           Marcin Szamotulski <coot@coot.me>
author:               IOG
synopsis:             Examine values for unexpected thunks
description:
    Long lived application data typically should not contain
    any thunks. This library can be used to examine values for
    unexpected thunks, which can then be used in assertions.
    This can be invaluable in avoiding memory leaks, or tracking
    down existing ones.

category:             Development
abi:                  09dbe9f08a700e1c1c6a103528d09e35
exposed:              True
exposed-modules:      NoThunks.Class
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nothunks
hs-libraries:         HSnothunks-0.2.0-2ulzmpjUEa322mVC3x8bCg
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-heap-9.4.8
    stm-2.5.1.0 text-2.0.2 time-1.12.2
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-nothunks/html/nothunks.haddock
haddock-html:         /usr/share/doc/haskell-nothunks/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-nothunks-0.2.0-44-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-nothunks.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 nothunks
version:              0.2.0
visibility:           public
id:                   nothunks-0.2.0-L4cINBk3sRmDtdUanatHgm
key:                  nothunks-0.2.0-L4cINBk3sRmDtdUanatHgm
license:              Apache-2.0
copyright:            2018-2024 Input Output Global Inc (IOG)
maintainer:           Marcin Szamotulski <coot@coot.me>
author:               IOG
synopsis:             Examine values for unexpected thunks
description:
    Long lived application data typically should not contain
    any thunks. This library can be used to examine values for
    unexpected thunks, which can then be used in assertions.
    This can be invaluable in avoiding memory leaks, or tracking
    down existing ones.

category:             Development
abi:                  b73c852a758912fd50df37c0140745d8
exposed:              True
exposed-modules:      NoThunks.Class
import-dirs:          /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/nothunks-0.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-nothunks
hs-libraries:         HSnothunks-0.2.0-L4cINBk3sRmDtdUanatHgm
depends:
    base-4.17.2.1 bytestring-0.11.5.3 containers-0.6.7 ghc-heap-9.4.8
    stm-2.5.1.0 text-2.0.2 time-1.12.2
    vector-0.13.2.0-F8322NeNtfL69paM3N9AVt

haddock-interfaces:   /usr/share/doc/haskell-nothunks/html/nothunks.haddock
haddock-html:         /usr/share/doc/haskell-nothunks/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
